(nap_list)=
# napari Advancement Proposals (NAPs)

NAPs document any major changes or proposals to the napari project.

## List of NAPs

```{tableofcontents}
```

```{toctree}
---
hidden:
---
template
```
